import React, { Component, PropTypes } from 'react';

export default class AUITooltip extends Component {
    render() {
        const { gravity, children, style, ...otherProps } = this.props;
        return (
            <div role='tooltip' className={`tipsy tipsy-${gravity}`} style={style} {...otherProps}>
                <div className={`tipsy-arrow tipsy-arrow-${gravity}`}/>
                <div className='tipsy-inner'>{children}</div>
            </div>
        );
    }
}

AUITooltip.displayName = 'AUITooltip';

AUITooltip.defaultProps = {
    style: {}
};

AUITooltip.propTypes = {
    /**
     * Children elements such as title for the tooltip
     */
    children: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.element
    ]),
    /**
     * Direction and position for the tooltip
     */
    gravity: PropTypes.oneOf(['n', 'ne', 'e', 'se', 's', 'sw', 'w', 'nw']).isRequired,
    /**
     * Custom style
     */
    style: PropTypes.object,
    /**
     * On mouse enter event handler
     */
    onMouseEnter: PropTypes.func,
    /**
     * On mouse leave event handler
     */
    onMouseLeave: PropTypes.func
};
