import React from 'react';
import { renderToStaticMarkup } from 'react-dom/server';
import ReactTestUtils from 'react-addons-test-utils';
const shallowRenderer = ReactTestUtils.createRenderer();

import AUIApplicationHeader from '../src/AUIApplicationHeader';
import AUIApplicationLogo from '../src/AUIApplicationLogo';

import proxyquire from 'proxyquire';
import { createStubComponent } from './StubComponent';

proxyquire.noCallThru();

import { expect } from 'chai';

describe('AUIApplicationHeader', () => {
    describe('Markup', () => {
        let StubbedAUIApplicationHeader;
        beforeEach(() => {
            StubbedAUIApplicationHeader = proxyquire('../src/AUIApplicationHeader', {
                './AUIApplicationLogo': createStubComponent('AUIApplicationLogo'),
                './AUINav': createStubComponent('AUINav')
            }).default;
        });
        /*eslint-disable*/
        it('should render the correct markup for the header', () => {
            expect(renderToStaticMarkup(<AUIApplicationHeader />)).to.equal(`<header id="header" role="banner"><nav class="aui-header aui-dropdown2-trigger-group" data-aui-response="true" role="navigation"><div class="aui-header-inner"><div class="aui-header-primary"><h1 class="aui-header-logo" id="logo"><a href="/"><span class="aui-header-logo-device"></span></a></h1></div><div class="aui-header-secondary"></div></div></nav></header>`);
        });
        /*eslint-enable*/
    });

    it('should render a logo with a headerLink of "/" by default', () => {
        shallowRenderer.render(<AUIApplicationHeader logo="confluence" />);
        const renderedTree = shallowRenderer.getRenderOutput();

        expect(renderedTree.props.children.props.children.props.children[0].props.children[0].type).to.equal(AUIApplicationLogo);
        expect(renderedTree.props.children.props.children.props.children[0].props.children[0].props.headerLink).to.equal('/');
    });

    it('should render a logo with a headerLink of "/confluence"', () => {
        shallowRenderer.render(<AUIApplicationHeader logo="confluence" headerLink="/confluence" />);
        const renderedTree = shallowRenderer.getRenderOutput();

        expect(renderedTree.props.children.props.children.props.children[0].props.children[0].type).to.equal(AUIApplicationLogo);
        expect(renderedTree.props.children.props.children.props.children[0].props.children[0].props.headerLink).to.equal('/confluence');
    });
});
