import React from 'react';
import { renderToStaticMarkup } from 'react-dom/server';
import ReactTestUtils from 'react-addons-test-utils';
const shallowRenderer = ReactTestUtils.createRenderer();

import { expect } from 'chai';
import AUIIcon from '../src/AUIIcon';
import AUIButton from '../src/AUIButton';

describe('AUIButton', () => {
    it('should render the correct AUI markup for a default button', () => {
        expect(renderToStaticMarkup(<AUIButton>Default button</AUIButton>)).to.equal(`<button class="aui-button">Default button</button>`);
    });

    it('should render the correct AUI markup for a primary button', () => {
        expect(renderToStaticMarkup(<AUIButton type="primary">Primary</AUIButton>)).to.equal(`<button class="aui-button aui-button-primary">Primary</button>`);
    });

    it('should render the correct AUI markup for a subtle button', () => {
        expect(renderToStaticMarkup(<AUIButton type="subtle">Subtle</AUIButton>)).to.equal(`<button class="aui-button aui-button-subtle">Subtle</button>`);
    });

    it('should render an AUI icon inside the button when an icon is provided', () => {
        shallowRenderer.render(<AUIButton icon="configure">Icon button</AUIButton>);
        const renderedTree = shallowRenderer.getRenderOutput();

        expect(renderedTree.props.children[0].props.children[0].type).to.equal(AUIIcon);
        expect(renderedTree.props.children[0].props.children[0].props.icon).to.equal('configure');
    });
});
