import React from 'react';
import { renderToStaticMarkup } from 'react-dom/server';

import { expect } from 'chai';
import AUIMessage from '../src/AUIMessage';

describe('AUIMessage', () => {
    it('should render to correct AUI markup when there is no title', () => {
        expect(renderToStaticMarkup(<AUIMessage>Hello world</AUIMessage>)).to.equal(`<div class="aui-message">Hello world</div>`);
    });

    it('should render to correct AUI markup when there is a title', () => {
        expect(renderToStaticMarkup(<AUIMessage title="NOTE">Hello world</AUIMessage>)).to.equal(`<div class="aui-message"><p class="title"><strong>NOTE</strong></p>Hello world</div>`);
    });

    it('should render the correct class for an error message', () => {
        expect(renderToStaticMarkup(<AUIMessage type="error">Error</AUIMessage>)).to.equal(`<div class="aui-message aui-message-error">Error</div>`);
    });

    it('should render the correct class for a warning message', () => {
        expect(renderToStaticMarkup(<AUIMessage type="warning">Warning</AUIMessage>)).to.equal(`<div class="aui-message aui-message-warning">Warning</div>`);
    });

    it('should render the correct class for a success message', () => {
        expect(renderToStaticMarkup(<AUIMessage type="success">Success</AUIMessage>)).to.equal(`<div class="aui-message aui-message-success">Success</div>`);
    });

    it('should render the correct class for a hint', () => {
        expect(renderToStaticMarkup(<AUIMessage type="hint">Hint</AUIMessage>)).to.equal(`<div class="aui-message aui-message-hint">Hint</div>`);
    });

    it('should render the correct class for an info message', () => {
        expect(renderToStaticMarkup(<AUIMessage type="info">Info</AUIMessage>)).to.equal(`<div class="aui-message aui-message-info">Info</div>`);
    });
});
