import React from 'react';
import { renderToStaticMarkup } from 'react-dom/server';
import { expect } from 'chai';
import AUINav from '../src/AUINav';

describe('AUINav', () => {
    it('should render an unordered list with the "aui-nav" class', () => {
        expect(renderToStaticMarkup(<AUINav />)).to.equal(`<ul class="aui-nav"></ul>`);
    });

    it('should render a single li child inside the container', () => {
        expect(renderToStaticMarkup(<AUINav><li>test</li></AUINav>)).to.equal(`<ul class="aui-nav"><li>test</li></ul>`);
    });

    it('should render multiple li children inside the container', () => {
        expect(renderToStaticMarkup(<AUINav><li>test</li><li><a href="#">test2</a></li></AUINav>)).to.equal(`<ul class="aui-nav"><li>test</li><li><a href="#">test2</a></li></ul>`);
    });

    it('should render data options inside the container', () => {
        const mockOptions = [
            <a>Link 1</a>,
            <a>Link 2</a>
        ];

        expect(renderToStaticMarkup(<AUINav options={mockOptions} />)).to.equal(`<ul class="aui-nav"><li><a>Link 1</a></li><li><a>Link 2</a></li></ul>`);
    });
});
